@@ -24,7 +24,7 @@ use std::error;
 use std::fmt;
 use std::sync::Arc;
 
-use chrono::{DateTime, Utc};
+use chrono::{DateTime, NaiveDate, Utc};
 use reqwest::{header, Client, Method, Request, StatusCode, Url};
 use schemars::JsonSchema;
 use serde::{Deserialize, Serialize};
@@ -659,7 +659,7 @@ pub struct Reimbursement {
     #[serde(default, skip_serializing_if = "String::is_empty")]
     pub user_id: String,
     pub created_at: DateTime<Utc>,
-    pub transaction_date: DateTime<Utc>,
+    pub transaction_date: NaiveDate,
     #[serde(default, skip_serializing_if = "String::is_empty")]
     pub id: String,
     #[serde(default, skip_serializing_if = "String::is_empty")]
